@@ -336,7 +336,19 @@ class LDPViewSetGenerator(ModelViewSet):
 
         # append nested fields to the urls list
         for field in kwargs.get('nested_fields') or cls.nested_fields:
-            urls.append(re_path('^' + detail_expr + field + '/', cls.nested_urls(field, **kwargs)))
+            # the nested property may have a custom viewset defined
+            try:
+                nested_model = kwargs['model']._meta.get_field(field).related_model
+            except FieldDoesNotExist:
+                nested_model = getattr(kwargs['model'], field).field.model
+
+            if hasattr(nested_model, 'get_view_set'):
+                kwargs['view_set'] = nested_model.get_view_set()
+                urls_fct = kwargs['view_set'].nested_urls  # our custom view_set may override nested_urls
+            else:
+                urls_fct = cls.nested_urls
+
+            urls.append(re_path('^' + detail_expr + field + '/', urls_fct(field, **kwargs)))
 
         return include(urls)
 
